/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core.auth;

import javax.annotation.Nullable;
import net.java.truelicense.core.codec.Codec;

/**
 * Defines authentication services.
 *
 * @author Christian Schlichtherle
 */
public interface Authentication extends AuthenticationParametersProvider {

    /**
     * Encodes and signs the given {@code artifact} in the provided
     * repositoryProvider and returns an artifactory for it.
     * After calling this method, the repositoryProvider typically gets encoded for
     * future decoding and verification.
     * <p>
     * It is an implementation detail whether or not signing {@code null} is
     * supported or not.
     *
     * @param  codec the codec for encoding the artifact.
     * @param  adapter the adapter of the model for encoding the artifact.
     * @param  artifact the artifact to sign.
     */
    <A> Artifactory<A> sign(Codec codec, Repository adapter, @Nullable A artifact)
    throws Exception;

    /**
     * Verifies the signature of the encoded artifact in the provided
     * repositoryProvider and returns an artifactory for it.
     * Calling this method generally requires prior initialization of the
     * repositoryProvider.
     * Though initialization is a side effect of calling {@link #sign}, this is
     * typically done by decoding the repositoryProvider.
     * <p>
     * It is an implementation detail whether or not verifying {@code null} is
     * supported or not.
     *
     * @param  codec the codec for decoding the artifact.
     * @param  adapter the adapter of the model for decoding the artifact.
     * @throws RepositoryIntegrityException if the integrity of this repositoryProvider
     *         with its encoded artifact has been compromised.
     */
    Artifactory<?> verify(Codec codec, Repository adapter) throws Exception;
}
